# prometheus-summary
Prometheus summary with quantiles over configurable sliding time window

## Installation
```
pip install prometheus-summary==0.1.6
```
This package can be found on [PyPI](https://pypi.org/project/prometheus-summary/).

## Documentation
Documentation is available on https://prometheus-summary.readthedocs.io/en/latest/.
